pub struct EventCache { /* private fields */ }Expand description
An event cache, providing lots of useful functionality for clients.
Cloning is shallow, and thus is cheap to do.
See also the module-level comment.
Implementations
Sourceimpl EventCache
impl EventCache
Sourcepub fn subscribe(&self) -> Result<()>
pub fn subscribe(&self) -> Result<()>
Starts subscribing the EventCache to sync responses, if not done
before.
Re-running this has no effect if we already subscribed before, and is cheap.
Sourcepub async fn clear_all_rooms(&self) -> Result<()>
pub async fn clear_all_rooms(&self) -> Result<()>
Cleanly clear all the rooms’ event caches.
This will notify any live observers that the room has been cleared.
Sourcepub fn subscribe_to_room_generic_updates(
&self,
) -> Receiver<RoomEventCacheGenericUpdate>
pub fn subscribe_to_room_generic_updates( &self, ) -> Receiver<RoomEventCacheGenericUpdate>
Subscribe to room generic updates.
If one wants to listen what has changed in a specific room, the
RoomEventCache::subscribe is recommended. However, the
RoomEventCacheSubscriber type triggers side-effects.
If one wants to get a high-overview, generic, updates for rooms, and
without side-effects, this method is recommended. For example, it
doesn’t provide a list of new events, but rather a
RoomEventCacheGenericUpdate::UpdateTimeline update. Also, dropping
the receiver of this channel will not trigger any side-effect.